"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[42],{66042:function(e,t,r){r.r(t),r.d(t,{FallthroughRoot:function(){return f}});var n=r(47515),i=r(62459),o=r(32667),s=r(67445),a=r(45519),l=r(78193),c=r(8192),p=r(9938),d=r(92761),u=r(63167),x=r(35936),h=function(){var e=(0,c.TH)(),t="".concat(e.pathname).concat(e.search);return(0,x.jsx)(c.l_,{to:"/instance".concat(t)})},f=function(){return(0,x.jsxs)(c.rs,{children:[(0,x.jsx)(c.AW,{path:["/runs/(.*)?","/assets/(.*)?","/scheduler"],children:(0,x.jsx)(h,{})}),(0,x.jsx)(c.AW,{path:"/home",children:(0,x.jsx)(g,{})}),(0,x.jsx)(c.AW,{path:"*",children:(0,x.jsx)(g,{})})]})},g=function(){var e=l.useContext(d.C5),t=e.allRepos,r=e.loading,h=e.locationEntries;if(r)return(0,x.jsx)(n.x,{flex:{direction:"row",justifyContent:"center"},style:{paddingTop:"100px"},children:(0,x.jsxs)(n.x,{flex:{direction:"row",alignItems:"center",gap:16},children:[(0,x.jsx)(i.$,{purpose:"section"}),(0,x.jsx)("div",{style:{color:o.w.Gray600},children:"Loading workspace\u2026"})]})});if(h.length&&0===t.length)return(0,x.jsx)(c.l_,{to:"/workspace"});var f=t.filter((function(e){return e.repository.pipelines.length>0}));if(f.every((function(e){return e.repository.pipelines.every((function(e){return(0,p.uc)(e.name)}))})))return(0,x.jsx)(c.l_,{to:"/instance/asset-graph"});if(1===f.length&&1===f[0].repository.pipelines.length){var g=f[0],j=g.repository.pipelines[0];return(0,x.jsx)(c.l_,{to:(0,u.jT)({repoName:g.repository.name,repoLocation:g.repositoryLocation.name,pipelineName:j.name,isJob:j.isJob})})}if(f.length>0)return(0,x.jsx)(c.l_,{to:"/instance"});var y=t[0];return(0,x.jsx)(n.x,{padding:{vertical:64},children:(0,x.jsx)(s.t,{icon:"no-results",title:y?"No jobs":"No repositories",description:y?"Your repository is loaded, but no jobs were found.":"Add a repository to get started.",action:(0,x.jsx)(a.fr,{href:"https://docs.dagster.io/getting-started",children:"View documentation"})})})};t.default=f},67445:function(e,t,r){r.d(t,{t:function(){return c}});r(78193);var n=r(47515),i=r(32667),o=r(73716),s=r(62459),a=r(83473),l=r(35936),c=function(e){var t=e.title,r=e.description,c=e.icon,p=e.action,d=e.shrinkable,u=1===[t,r,p].filter(Boolean).length;return(0,l.jsxs)(n.x,{flex:{gap:20,alignItems:u?"center":"flex-start"},background:i.w.Gray50,padding:24,style:{margin:"auto",borderRadius:8,width:d?"initial":"max-content",maxWidth:500},children:["spinner"===c?(0,l.jsx)(s.$,{purpose:"section"}):"no-results"===c?(0,l.jsx)(o.JO,{name:"search",size:48,color:i.w.Gray400}):(0,l.jsx)(o.JO,{name:c,size:48,color:i.w.Gray400}),(0,l.jsxs)(n.x,{flex:{gap:8,direction:"column",alignItems:"flex-start"},children:[t&&(0,l.jsx)(a.pm,{style:{color:i.w.Gray900},children:t}),r&&(0,l.jsx)("div",{style:{color:i.w.Gray500},children:r}),p]})]})}}}]);
//# sourceMappingURL=42.b4c349cc.chunk.js.map