"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[545],{9938:function(n,e,t){t.d(e,{ll:function(){return h}});var r,i,a,s=t(99500),o=t(69131),u=t(38608);(0,u.P)({source:function(n){return n.source},target:function(n){return n.target},x:function(n){return n.x},y:function(n){return n.y}});function h(n){return n.path.join(" > ")}var d=(0,o.Ps)(r||(r=(0,s.Z)(["\n  fragment InProgressRunsFragment on InProgressRunsByStep {\n    stepKey\n    unstartedRuns {\n      id\n    }\n    inProgressRuns {\n      id\n    }\n  }\n"]))),g=(0,o.Ps)(i||(i=(0,s.Z)(["\n  fragment LastRunsWarningsFragment on LatestRun {\n    stepKey\n    run {\n      id\n      status\n    }\n  }\n"])));(0,o.Ps)(a||(a=(0,s.Z)(["\n  fragment RepositoryLiveFragment on Repository {\n    id\n    name\n    location {\n      id\n      name\n    }\n    inProgressRunsByStep {\n      ...InProgressRunsFragment\n    }\n    latestRunByStep {\n      __typename\n      ...LastRunsWarningsFragment\n    }\n  }\n  ","\n  ","\n"])),d,g)},50545:function(n,e,t){t.r(e),t.d(e,{layoutAssetGraph:function(){return o},getForeignNodeDimensions:function(){return u},ASSET_NODE_ANNOTATIONS_MAX_WIDTH:function(){return h},ASSET_NODE_NAME_MAX_LENGTH:function(){return d},getAssetNodeDimensions:function(){return g}});var r=t(83975),i=t(9938),a=100,s=!1,o=function(n){var e=new r.graphlib.Graph;e.setGraph({rankdir:"TB",marginx:a,marginy:a,nodesep:s?20:50,edgesep:10,ranksep:s?20:50}),e.setDefaultEdgeLabel((function(){return{}}));var t=function(n){return n&&n.definition.opName};Object.values(n.nodes).filter(t).forEach((function(n){var t=g(n.definition),r=t.width,i=t.height;e.setNode(n.id,{width:s?230:r,height:i})}));var i={};Object.keys(n.downstream).forEach((function(r){Object.keys(n.downstream[r]).forEach((function(a){(t(n.nodes[a])||t(n.nodes[r]))&&(e.setEdge({v:r,w:a},{weight:1}),t(n.nodes[a])?t(n.nodes[r])||(i[r]=!0):i[a]=!0)}))})),Object.keys(i).forEach((function(n){e.setNode(n,u(n))})),r.layout(e);var o={};e.nodes().forEach((function(n){var t=e.node(n);t&&(o[n]=t)}));var h=0,d=0,c={};Object.keys(o).forEach((function(n){var e=o[n];c[n]={id:n,bounds:{x:e.x-e.width/2,y:e.y-e.height/2,width:e.width,height:e.height}},h=Math.max(h,e.x+e.width/2),d=Math.max(d,e.y+e.height/2)}));var f=[];return e.edges().forEach((function(n){var t=e.edge(n).points;f.push({from:t[0],to:t[t.length-1],dashed:!1})})),{nodes:c,edges:f,width:h+a,height:d+a}},u=function(n){var e=JSON.parse(n);return{width:8*(0,i.ll)({path:e}).length+30,height:30}},h=65,d=50,g=function(n){var e=75;n.description&&(e+=25);var t=(0,i.ll)(n.assetKey);return n.opName&&t!==n.opName&&(e+=25),{width:Math.max(200,8*Math.min(d,t.length))+h,height:e}}}}]);
//# sourceMappingURL=545.4c9cf810.chunk.js.map